from abc import ABC

from platypush.plugins.sensor import SensorPlugin


class GpioSensorPlugin(SensorPlugin, ABC):
    pass


# vim:sw=4:ts=4:et:
